summaryrefslogtreecommitdiffstats
path: root/drivers/staging/tidspbridge/include/dspbridge/drv.h
diff options
context:
space:
mode:
authorRene Sapiens2010-07-10 04:24:02 +0200
committerGreg Kroah-Hartman2010-07-22 19:45:35 +0200
commitfb6aabb7f8b64aef7c4376b6cd4b760a62f75c5b (patch)
treee887979c80033a4656704455b9c7279448e7cdad /drivers/staging/tidspbridge/include/dspbridge/drv.h
parentstaging: ti dspbridge: Rename words with camel case (diff)
downloadkernel-qcow2-linux-fb6aabb7f8b64aef7c4376b6cd4b760a62f75c5b.tar.gz
kernel-qcow2-linux-fb6aabb7f8b64aef7c4376b6cd4b760a62f75c5b.tar.xz
kernel-qcow2-linux-fb6aabb7f8b64aef7c4376b6cd4b760a62f75c5b.zip
staging: ti dspbridge: Rename words with camel case
The intention of this patch is to rename the remaining variables with camel case. Variables will be renamed avoiding camel case and Hungarian notation. The words to be renamed in this patch are: ======================================== pMemStatBuf to mem_stat_buf pMgrAttrs to mgr_attrts pMgrInfo to mgr_info pNodeEnv to node_env pNodeId to node_uuid pNodeInfo to node_info pNumLibs to num_libs pNumPersLibs to num_pers_libs pObjDef to obj_def pObjUuid to obj_uuid poolPhysBase to pool_phys_base poolSize to pool_size pPctxt to pctxt ppDevContext to dev_cntxt ppDrvInterface to drv_intf pPersistentDepLibs to prstnt_dep_libs pPhyAddr to phy_addr ======================================== Signed-off-by: Rene Sapiens <rene.sapiens@ti.com> Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>
Diffstat (limited to 'drivers/staging/tidspbridge/include/dspbridge/drv.h')
-rw-r--r--drivers/staging/tidspbridge/include/dspbridge/drv.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/drivers/staging/tidspbridge/include/dspbridge/drv.h b/drivers/staging/tidspbridge/include/dspbridge/drv.h
index 2f9d8d8364d0..604c15bda5f9 100644
--- a/drivers/staging/tidspbridge/include/dspbridge/drv.h
+++ b/drivers/staging/tidspbridge/include/dspbridge/drv.h
@@ -430,15 +430,15 @@ void bridge_recover_schedule(void);
* allocations.
* physical address based on the page frame address.
* Parameters:
* poolPhysBase starting address of the physical memory pool.
* poolSize size of the physical memory pool.
* Returns:
* none.
* Requires:
* - MEM initialized.
* - valid physical address for the base and size > 0
*/
-extern void mem_ext_phys_pool_init(IN u32 poolPhysBase, IN u32 poolSize);
+extern void mem_ext_phys_pool_init(IN u32 pool_phys_base, IN u32 pool_size);
/*
* ======== mem_ext_phys_pool_release ========
@@ -502,7 +502,7 @@ extern void mem_free_phys_mem(void *pVirtualAddress,
* If valid linear address is returned, be sure to call
* MEM_UNMAP_LINEAR_ADDRESS().
*/
-#define MEM_LINEAR_ADDRESS(pPhyAddr, byte_size) pPhyAddr
+#define MEM_LINEAR_ADDRESS(phy_addr, byte_size) phy_addr
/*
* ======== MEM_UNMAP_LINEAR_ADDRESS ========
@@ -430,15 +430,15 @@ void bridge_recover_schedule(void);
* physical address based on the page frame address.
* Parameters:
- * poolPhysBase starting address of the physical memory pool.
- * poolSize size of the physical memory pool.
+ * pool_phys_base starting address of the physical memory pool.
+ * pool_size size of the physical memory pool.
* Returns:
* none.